(* ********************************************************* *)
(* *****                                               ***** *)
(* *****  FeynRules model file: stop_scharm            ***** *)
(* *****  Author: B. Fuks                              ***** *)
(* *****                                               ***** *)
(* ********************************************************* *)


(* ************************** *)
(* *****  Information   ***** *)
(* ************************** *)
M$ModelName = "stop_scharm";

M$Information = {
  Authors      -> {"Benjamin Fuks"}, 
  Date         ->  "20.06.17",
  Version      ->  "1.0",
  Institutions -> {"LPTHE / UPMC"},
  Emails       -> {"fuks@lpthe.jussieu.fr"}
};

(* Change log *)
(* v1.0: implementation of the stop_scharm mixing model *)

(* ************************** *)
(* *****     Fields     ***** *)
(* ************************** *)
IndexRange[Index[SCA]] = Range[2]; IndexStyle[SCA, i];

M$ClassesDescription = {
  (* gluino  and neutralino *)
  F[21] == { ClassName -> go,  SelfConjugate -> True, Indices -> {Index[Gluon]}, Mass -> {Mgo,500}, Width -> {Wgo,10}, PDG -> 1000021 },
  F[31] == { ClassName -> chi, SelfConjugate -> True, Mass -> {Mchi,50}, Width -> 0, PDG -> 1000022 },

  (* Squarks *)
  S[20] == { ClassName -> sq,  SelfConjugate -> False, Indices -> {Index[SCA],Index[Colour]}, FlavorIndex->SCA, QuantumNumbers->{Q->2/3},
            ClassMembers->{sq1,sq2}, Mass -> {Msq,{Msq1, 400},{Msq2,800}}, Width -> {{Wsq1,10},{Wsq2,10}}, PDG->{1000006,2000006} },
  S[31] == { ClassName -> scR, Unphysical->True, SelfConjugate -> False, Indices -> {Index[Colour]}, QuantumNumbers -> {Q->2/3}, Definitions -> { scR[a_] -> ct sq1[a] - st sq2[a]} },
  S[32] == { ClassName -> stR, Unphysical->True, SelfConjugate -> False, Indices -> {Index[Colour]}, QuantumNumbers -> {Q->2/3}, Definitions -> { stR[a_] -> st sq1[a] + ct sq2[a]} }

};

(* ************************** *)
(* *****   Parameters   ***** *)
(* ************************** *)
M$Parameters = {
  theta == { ParameterType->External, BlockName -> SQMIX, Value -> 1.57, Description -> "Stop-scharm mixing angle"},
  ct    == { ParameterType->Internal, TeX -> Subscript[c,\[Theta]], Value -> Cos[theta], Description -> "Cosine of the stop-scharm mixing angle" },
  st    == { ParameterType->Internal, TeX -> Subscript[s,\[Theta]], Value -> Sin[theta], Description -> "Sine of the stop-scharm mixing angle" }
};


(* ************************** *)
(* *****   Lagrangian   ***** *)
(* ************************** *)
Lkin :=  ExpandIndices[I/2 gobar.Ga[mu].DC[go,mu] - 1/2 Mgo gobar.go + I/2 chibar.Ga[mu].del[chi,mu] - 1/2 Mchi chibar.chi +
       DC[scRbar[cc],mu] DC[scR[cc],mu] + DC[stRbar[cc],mu] DC[stR[cc],mu] - Msq^2 sqbar[ff,cc] sq[ff,cc],FlavorExpand->SCA];

LD := -1/2 gs^2 T[a,cc1,cc2] T[a,cc3,cc4] * (scRbar[cc1] scR[cc2] + stRbar[cc1] stR[cc2]) * (scRbar[cc3] scR[cc4] + stRbar[cc3] stR[cc4]);

Lgosqq :=  Sqrt[2] gs ProjM[s1,s2] * ( cbar[s1,cc1].go[s2,a] T[a,cc1,cc2] scR[cc2] + tbar[s1,cc1].go[s2,a] T[a,cc1,cc2] stR[cc2]);

Ldec:=  Sqrt[2] g1 ProjM[s1,s2] * ( cbar[s1,cc1].chi[s2] (2/3) scR[cc1] + tbar[s1,cc1].chi[s2] (2/3) stR[cc1]);

LSUSY := Lkin + LD + Lgosqq + Ldec + HC[Lgosqq + Ldec];
